/* DESIGNING SINGLE TILE MINIGAMES
If you want to design single tile minigames for submission to
BYONDscape, you should follow these guidelines:

* Include this library in your entries so all the standard minigame
	controls will be present. Minigames must be a child of /turf/minigame
	(Example: /turf/minigame/demo_game.) Do not alter the /turf/minigame
	parent!

* The minigame cabinet and playfield must fit within a single 32x32 tile.
	Incidental features such as pool cues, foosball handles, pinball
	plungers, win game fireworks, etc. may extend into adjacent tiles WHILE
	THE GAME IS PLAYED. An inactive game must remain within 32x32 pixels.

* The minigame should be self contained, using only procs and vars
	that belong to it. It may make minor adjustments to player vars.
	(Example: checking to be sure a mob is south of the game before they
	can begin play, and turning the mob to face the minigame object when
	they begin play.)

	o DO NOT add new procs, verbs, or vars to existing game objects such
		as mobs or clients.

	o There are built in minigame procs (described below) provided by the
		game world to allow arrow key input from players and let a minigame
		sense when a player bumps into it or walks away (hits Esc).

* If the minigame requires game pieces to be separate atoms, they should
	be a child of /atom/movable/minigame_piece. For a checkers game, the
	checkers would be /atom/movable/minigame_piece/checker. This allows
	developers who use one or more of these standardized minigames to
	easily disable the main game's verbs for all minigame pieces.

	For example, if movable atoms have a get() verb in a particular
	game, the developer can hide it and keep it from working on
	minigame_pieces by including this in their code:

		atom/movable/minigame_piece/get()
			set hidden = 1	// hide this verb
			return			// do nothing

* The minigame must provide a way to begin play, whether through verbs,
	the GameBumped() proc, or clicking the game. Players may exit the minigame
	at any time, which will call the minigame's Quit proc.

	To link a player to the game so that player input may be trapped, set
	the player's client Game var equal to the minigame object.
	Example:
		turf/minigame/pinball_game/GameBumped(mob/M)
			if(!M.client) return	// NPCs don't get to play!
			if(get_dir(M,src)==NORTH)	// the game is above the player
				viewers(world.view,M) << "[M] drops a quarter into [src] \
					and begins to play."
				M.client.Game = src
				player = M	// custom var to track who is playing this game
				StartGame()	// custom proc to flash the lights and begin
			else
				M << "You'll have to stand in front of [src] to play it."

* When the minigame ends, there may be a short win/lose game event that
	lasts no longer than 30 seconds. After the end game event, the
	minigame should become dormant with no active or sleeping procs in
	order to conserve game resources.

* The minigame must provide instructions by overriding the built in
	instructions() verb. Instructions may be displayed in the browser, a
	browser popup, or the normal text box (if they are brief). Please do
	not use alert boxes for game instructions.

* Sounds played by the game should only be audible within 2 tiles of the
	game. (Example: hearers(2,src) << sound('wingame.wav') )

* Keep in mind that this is a MINIGAME. It must fit into a larger game
	world without producing strain on the server. Keep processor and
	bandwidth requirements as low as possible.

MINIGAME PROCS:
These procs are built into the /turf/minigame to standardize player input.
Override them to provide custom interaction. You are encouraged to use
custom verbs and the Click() proc for player input as well.

instructions()
	This verb must be overridden to provide usr with game instructions,
	either in the browser, a browser popup, or the text box if it is
	brief. Please DO NOT use alert boxes for game instructions.

GameBumped(mob/M)
	Called when mob/M bumps into the minigame.

PlayerInput(mob/M, Dir)
	Called when mob M presses an arrow key while the mob is linked to the
	game. Dir is 0 if the player presses the center 5 key on the numpad.

Quit(mob/M)
	Called when mob M quit the game by using the esc key. This proc must
	not have a sleep() call in it because that would prevent players from
	being able to exit the game at their whim. The EscapeKey() verb has
	already verified that the player wants to quit by the time this proc is
	called.
*/
